.. _landing_page:

Thoth's landing page
--------------------

Here you can find all the relevant information if you want to get in touch with
us or get involved.

Generic Information
===================

* `Main page <https://thoth-station.ninja>`__
* `YouTube channel <https://www.youtube.com/channel/UClUIDuq_hQ6vlzmqM59B2Lw>`__
* `Project board <https://github.com/orgs/thoth-station/projects/>`__
* `Twitter <https://twitter.com/ThothStation>`__
* `Conference talks and articles published <https://github.com/thoth-station/talks>`__
* `Datasets <https://github.com/thoth-station/datasets>`__

Contact us
==========

If you do not find required information or get in touch, feel free to contact
us in `Google Chat room <https://chat.google.com/room/AAAAVjnVXFk>`__. If you
are an external contributor, feel free to request access in `thoth-station/support
repository <https://github.com/thoth-station/support>`__ by `opening an issue
<https://github.com/thoth-station/support/issues/new/choose>`__.

Community meetings & Event Calendar
===================================

Follow instructions in the `thoth-station/core repository
<https://github.com/thoth-station/core/blob/master/README.rst>`__ to find
interesting sessions we do.

Special Interest Groups
=======================

The whole team is formed into "Special Interest Groups" (SIG). More info can be
found in the `thoth-station/core repository
<https://github.com/thoth-station/core/blob/master/community/sig-list.md>`__.

Red Hat mailing list
====================

You can subscribe to ``aicoe`` and ``aicoe-thoth`` Red Hat internal mailing
lists for project updates and discussion.

Cooperation with Thoth
======================

Internship
##########

Each year we work with university students which are involved in the project
and can gain valuable technical experience with cutting edge technologies.
Besides technical knowledge and experience, this cooperation also brings the
feel of `open source culture we support
<https://www.redhat.com/en/about/our-culture>`__. If you want to get in, do not
hesitate to contact us. Some of our colleages participated in this process and
are very valuable engineers in our team. We work with Boston University, Brno
University of Technology and Masaryk University but we are open to work with
other universities as well.

Bachelor and Diploma Theses
###########################

If you are a university student seeking for a bachelor or diploma thesis, we
can offer a cooperation. An example of bachelor and diploma thesis we did with
a coop with Brno University of Technology and Brno Masaryk University:

* `Checking performance characteristics of AI/ML libraries <https://research.redhat.com/blog/engineering_project/checking-performance-characteristics-of-ai-ml-libraries/>`__
* `Distributed machine learning training on OpenShift <https://research.redhat.com/blog/engineering_project/distributed-machine-learning-training-on-openshift/>`__
* `Predicting software stack issues in popular AI/ML libraries <https://research.redhat.com/blog/engineering_project/predicting-software-stack-issues-in-popular-ai-ml-libraries/>`__

We are not limited to the university listing stated. Also, we are not limited
to the listing of available projects on `Red Hat research site
<https://research.redhat.com/>`__. If you want to sign up for a thesis with us,
do not hesitate to contact us. We can discuss your ideas or create a thesis
suitable for you.
